OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Lisätty suosikkeihin",
    "Removed from favorites" : "Poistettu suosikeista",
    "You added {file} to your favorites" : "Lisäsit tiedoston {file} suosikkeihin",
    "You removed {file} from your favorites" : "Poistit tiedoston {file} suosikeista",
    "Favorites" : "Suosikit",
    "File changes" : "Tiedostomuutokset",
    "Created by {user}" : "Tekijänä {user}",
    "Changed by {user}" : "Muokkaajana {user}",
    "Deleted by {user}" : "Poistanut {user}",
    "Restored by {user}" : "Palauttanut {user}",
    "Renamed by {user}" : "Uudelleennimennyt {user}",
    "Moved by {user}" : "Siirtänyt {user}",
    "\"remote account\"" : "\"etätili\"",
    "You created {file}" : "Loit tiedoston {file}",
    "You created an encrypted file in {file}" : "Loit salatun tiedoston {file}",
    "{user} created {file}" : "{user} loi tiedoston {file}",
    "{user} created an encrypted file in {file}" : "{user} loi salatun tiedoston {file}",
    "{file} was created in a public folder" : "Tiedosto {file} luotiin julkisessa kansiossa",
    "You changed {file}" : "Muutit tiedostoa {file}",
    "You changed an encrypted file in {file}" : "Muutit salattua tiedostoa {file}",
    "{user} changed {file}" : "{user} muutti tiedostoa {file}",
    "{user} changed an encrypted file in {file}" : "{user} muutti salattua tiedostoa {file}",
    "You deleted {file}" : "Poistit tiedoston {file}",
    "You deleted an encrypted file in {file}" : "Poistit salatun tiedoston {file}",
    "{user} deleted {file}" : "{user} poisti tiedoston {file}",
    "{user} deleted an encrypted file in {file}" : "{user} poisti salatun tiedoston {file}",
    "You restored {file}" : "Palautit tiedoston {file}",
    "{user} restored {file}" : "{user} palautti tiedoston {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Uudelleennimesit tiedoston {oldfile} (piilotettu) tiedostoksi {newfile} (piilotettu)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Uudelleennimesit tiedoston {oldfile} (piilotettu) tiedostoksi {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Uudelleennimesit tiedoston {oldfile} tiedostoksi {newfile} (piilotettu)",
    "You renamed {oldfile} to {newfile}" : "Annoit tiedostolle {oldfile} uuden nimen {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} uudelleennimesi tiedoston {oldfile} (piilotettu) tiedostoksi {newfile} (piilotettu)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} uudelleennimesi tiedoston {oldfile} (piilotettu) tiedostoksi {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} uudelleennimesi tiedoston {oldfile} tiedostoksi {newfile} (piilotettu)",
    "{user} renamed {oldfile} to {newfile}" : "{user} uudelleennimesi tiedoston {oldfile} tiedostoksi {newfile}",
    "You moved {oldfile} to {newfile}" : "Siirsit tiedoston {oldfile} tiedostoksi {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} siirsi tiedoston {oldfile} tiedostoksi {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Tiedosto on lisätty tai poistettu <strong>suosikeista</strong>",
    "Files" : "Tiedostot",
    "A file or folder has been <strong>changed</strong>" : "Tiedostoa tai kansiota on <strong>muutettu</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Suosikkitiedostoa tai -kansiota on <strong>muutettu</strong>",
    "Failed to authorize" : "Valtuuttaminen epäonnistui",
    "Invalid folder path" : "Virheellinen kansion polku",
    "Folder not found" : "Kansiota ei löytynyt",
    "The file cannot be found" : "Tiedostoa ei löytynyt",
    "The destination path does not exist: %1$s" : "Kohdepolkua ei ole olemassa: %1$s",
    "You do not have permission to create a file at the specified location" : "Sinulla ei ole oikeutta luoda tiedostoa määriteltyyn sijaintiin.",
    "The file could not be converted." : "Tiedostoa ei voitu muuntaa.",
    "Could not get relative path to converted file" : "Muunnetun tiedoston suhteellista polkua ei voitu hakea",
    "Limit must be a positive integer." : "Rajan tulee olla positiivinen kokonaisluku.",
    "The replacement character may only be a single character." : "Korvaava merkki voi olla yksi ainoa merkki.",
    "Filename sanitization already started." : "Tiedostonimien siistiminen on jo aloitettu.",
    "Favorite files" : "Suosikkitiedostot",
    "No favorites" : "Ei suosikkeja",
    "More favorites" : "Lisää suosikeja",
    "Accept" : "Hyväksy",
    "Reject" : "Hylkää",
    "Incoming ownership transfer from {user}" : "Saapuva omistajuuden siirto käyttäjältä {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Hyväksytkö kohteen {path}?\n\nHuomio: Siirtotoimenpiteet hyväksynnän jälkeen saattavat kestää tunnin.",
    "Ownership transfer denied" : "Omistajuuden siirto kielletty",
    "Ownership transfer failed" : "Omistajuuden siirto epäonnistui",
    "Your ownership transfer of {path} to {user} failed." : "Kohteen {path} omistajuussiirtosi käyttäjälle {user} epäonnistui.",
    "The ownership transfer of {path} from {user} failed." : "Kohteen {path} omistajuussiirto käyttäjälle {user} epäonnistui.",
    "Ownership transfer done" : "Omistajuuden siirto valmis",
    "Your ownership transfer of {path} to {user} has completed." : "Kohteen {path} omistajuussiirto käyttäjälle {user} valmistui.",
    "The ownership transfer of {path} from {user} has completed." : "Kohteen {path} omistajuussiirto käyttäjältä {user} valmistui.",
    "in %s" : "polussa %s",
    "File Management" : "Tiedostohallinta",
    "Home" : "Koti",
    "Target folder does not exist any more" : "Kohdekansiota ei ole enää olemassa",
    "Reload current directory" : "Lataa nykyinen kansio uudelleen",
    "Go to the \"{dir}\" directory" : "Siirry kansioon \"{dir}\"",
    "Current directory path" : "Nykyisen kansion polku",
    "Your have used your space quota and cannot upload files anymore" : "Olet käyttänyt tilakiintiösi, joten et voi lähettää enempää tiedostoja",
    "You do not have permission to upload or create files here." : "Käyttöoikeutesi eivät riitä tiedostojen lähettämiseen tai luomiseen tänne.",
    "Drag and drop files here to upload" : "Vedä ja pudota tiedostot tähän lähettääksesi",
    "Favorite" : "Suosikki",
    "Back" : "Takaisin",
    "File is loading" : "Tiedostoa ladataan",
    "Folder is loading" : "Kansiota ladataan",
    "Filename" : "Tiedostonimi",
    "Folder name" : "Kansion nimi",
    "Invalid filename." : "Epäkelpo tiedostonimi.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Kohteen \"{oldName}\" uudeksi nimeksi asetettiin \"{newName}\"",
    "Rename file" : "Nimeä tiedosto uudelleen",
    "Folder" : "Kansio",
    "Unknown file type" : "Tuntematon tiedostotyyppi",
    "{ext} image" : "{ext} kuva",
    "{ext} video" : "{ext} video",
    "{ext} audio" : "{ext} ääni",
    "{ext} text" : "{ext} teksti",
    "Pending" : "Odottaa",
    "Unknown date" : "Tuntematon päivämäärä",
    "Clear filter" : "Tyhjennä suodatin",
    "Modified" : "Muokattu",
    "Search everywhere" : "Etsi kaikkialta",
    "Type" : "Tyyppi",
    "Active filters" : "Aktiiviset suodattimet",
    "Remove filter" : "Poista suodatin",
    "Appearance" : "Ulkoasu",
    "Show hidden files" : "Näytä piilotetut tiedostot",
    "Show file type column" : "Näytä tiedostotyypin sarake",
    "Show file extensions" : "Näytä tiedostopäätteet",
    "Crop image previews" : "Rajaa kuvien esikatseluja",
    "General" : "Yleiset",
    "Sort favorites first" : "Järjestä suosikit ensiksi",
    "Sort folders before files" : "Järjestä kansiot ennen tiedostoja",
    "Default view" : "Oletusnäkymä",
    "All files" : "Kaikki tiedostot",
    "Personal files" : "Henkilökohtaiset tiedostot",
    "Additional settings" : "Lisäasetukset",
    "Actions" : "Toiminnot",
    "File actions" : "Tiedostotoiminnot",
    "Selection" : "Valinta",
    "Select all files" : "Valitse kaikki tiedostot",
    "Deselect all" : "Poista valinnat",
    "Navigation" : "Navigointi",
    "Go to parent folder" : "Siirry ylätason kansioon",
    "Go to file above" : "Siirry yllä olevaan tiedostoon",
    "Go to file below" : "Siirry alla olevaan tiedostoon",
    "Go left in grid" : "Siirry vasemmalle ruudukossa",
    "Go right in grid" : "Siirry oikealle ruudukossa",
    "View" : "Näytä",
    "Toggle grid view" : "Ruudukkonäkymä päälle/pois",
    "Open file sidebar" : "Avaa tiedoston sivupalkki",
    "Warnings" : "Varoitukset",
    "Warn before changing a file extension" : "Varoita ennen tiedostopäätteen muuttamista",
    "WebDAV URL" : "WebDAV:in URL-osoite",
    "Create an app password" : "Luo sovellussalasana",
    "Name" : "Nimi",
    "File type" : "Tiedoston tyyppi",
    "Size" : "Koko",
    "{displayName}: done" : "{displayName}: valmis",
    "{displayName}: failed" : "{displayName}: epäonnistui",
    "(selected)" : "(valittu)",
    "List of files and folders." : "Luettelo tiedostoista ja kansioista.",
    "You have used your space quota and cannot upload files anymore." : "Olet käyttänyt tilakiintiösi, etkä voi enää ladata tiedostoja.",
    "Column headers with buttons are sortable." : "Painikkeilla varustetut sarakeotsikot ovat järjestettävissä.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Tätä luetteloa ei ole esitetty täysin suorituskykyyn liittyvistä syistä. Tiedostot esitetään sitä mukaa, kun selaat luetteloa.",
    "File not found" : "Tiedostoa ei löytynyt",
    "_{count} selected_::_{count} selected_" : ["{count} valittu","{count} valittu"],
    "Search here" : "Etsi tästä",
    "{usedQuotaByte} used" : "{usedQuotaByte} käytetty",
    "{used} of {quota} used" : "{used}/{quota} käytetty",
    "{relative}% used" : "{relative} % käytetty",
    "Could not refresh storage stats" : "Tallennustilan tilastoja ei voitu päivittää",
    "Your storage is full, files can not be updated or synced anymore!" : "Tallennustila on loppu, tiedostoja ei voi enää päivittää tai synkronoida!",
    "Storage information" : "Tallennustilan tiedot",
    "Storage quota" : "Tallennustilan kiintiö",
    "New folder" : "Uusi kansio",
    "Create new folder" : "Luo uusi kansio",
    "This name is already in use." : "Tämä nimi on jo käytössä.",
    "Create" : "Luo",
    "Files starting with a dot are hidden by default" : "Pisteellä alkavat tiedostot ovat oletusarvoisesti piilotettuja",
    "Failed to start filename sanitization." : "Tiedostonimien siistimisen käynnistäminen epäonnistui.",
    "Filename sanitization in progress." : "Tiedostonimien siistiminen käynnissä.",
    "Refresh" : "Päivitä",
    "Sanitization errors" : "Siistimisvirheet",
    "Windows filename support has been enabled." : "Windows-tiedostonimien tuki on otettu käyttöön.",
    "Sanitize filenames" : "Siisti tiedostonimet",
    "(starting)" : "(aloitetaan)",
    "Submit" : "Lähetä",
    "Choose a file or folder to transfer" : "Valitse siirrettävä tiedosto tai kansio",
    "Transfer" : "Siirrä",
    "Transfer {path} to {userid}" : "Siirrä {path} käyttäjälle {userid}",
    "Invalid path selected" : "Valittu virheellinen polku",
    "Unknown error" : "Tuntematon virhe",
    "Ownership transfer request sent" : "Pyyntö omistajuuden vaihdosta lähetetty",
    "Cannot transfer ownership of a file or folder you do not own" : "Et voi siirtää sellaisen tiedoston tai kansion omistajuutta, jota et itse omista",
    "Transfer ownership of a file or folder" : "Siirrä tiedoston tai kansion omistajuus",
    "Choose file or folder to transfer" : "Valitse siirrettävä tiedosto tai kansio",
    "Change" : "Muuta",
    "New owner" : "Uusi omistaja",
    "Keep {old}" : "Pidä {old}",
    "Keep without extension" : "Pidä ilman tiedostopäätettä",
    "Use {new}" : "Käytä {new}",
    "Remove extension" : "Poista tiedostopääte",
    "Change file extension" : "Vaihda tiedostopäätettä",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Tiedostopäätteen \"{old}\" muuttaminen muotoon \"{new}\" saattaa tehdä tiedostosta lukukelvottoman.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Tiedostopäätteen \"{old}\" poistaminen saattaa tehdä tiedostosta lukukelvottoman.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Tiedostopäätteen \"{new}\" lisääminen saattaa tehdä tiedostosta lukukelvottoman.",
    "Do not show this dialog again." : "Älä näytä uudelleen",
    "Select file or folder to link to" : "Valitse tiedosto tai kansio, johon linkitetään",
    "Choose {file}" : "Valitse {file}",
    "Files settings" : "Tiedostojen asetukset",
    "Share" : "Jaa",
    "Shared by link" : "Jaettu linkillä",
    "Shared" : "Jaettu",
    "Switch to list view" : "Vaihda taulukkonäkymään",
    "Switch to grid view" : "Vaihda ruudukkonäkymään",
    "The file could not be found" : "Tiedostoa ei löytynyt",
    "Upload was cancelled by user" : "Käyttäjä peruutti latauksen",
    "Not enough free space" : "Ei tarpeeksi vapaata tilaa",
    "Operation is blocked by access control" : "Pääsynhallinta estää toiminnon",
    "Error during upload: {message}" : "Virhe lähettäessä: {message}",
    "Error during upload, status code {status}" : "Virhe lähettäessä, tilakoodi {status}",
    "Unknown error during upload" : "Tuntematon virhe lähettämisen aikana",
    "Loading current folder" : "Ladataan nykyistä kansiota",
    "Retry" : "Yritä uudelleen",
    "No files in here" : "Täällä ei ole tiedostoja",
    "Upload some content or sync with your devices!" : "Lähetä tiedostoja tai synkronoi sisältö laitteidesi kanssa!",
    "Go back" : "Mene takaisin",
    "Views" : "Näkymät",
    "You" : "Sinä",
    "Shared multiple times with different people" : "Jaettu useita kertoja eri ihmisten kanssa",
    "Error while loading the file data" : "Virhe tiedostoa ladatessa",
    "Owner" : "Omistaja",
    "Remove from favorites" : "Poista suosikeista",
    "Add to favorites" : "Lisää suosikkeihin",
    "Tags" : "Tunnisteet",
    "Your files" : "Tiedostot",
    "Open in files" : "Avaa tiedostosovelluksessa",
    "File cannot be accessed" : "Tiedostoa ei voi käyttää",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Tiedostoa ei löytynyt tai oikeutesi eivät riitä sen katseluun. Pyydä lähettäjää jakamaan se.",
    "No search results for “{query}”" : "Ei tuloksia haulla “{query}”",
    "Search for files" : "Etsi tiedostoja",
    "Files compatibility" : "Tiedostojen yhteensopivuus",
    "Enforce Windows compatibility" : "Pakota Windows-yhteensopivuus",
    "Blank" : "Tyhjä",
    "Unable to create new file from template" : "Uutta tiedostoa mallipohjasta ei voi luoda",
    "Pick a template for {name}" : "Valtise mallipohja tiedostolle {name}",
    "Create a new file with the selected template" : "Luo uusi tiedosto valitulla mallipohjalla",
    "Creating file" : "Luodaan tiedostoa",
    "Save as {displayName}" : "Tallenna nimellä {displayName}",
    "Failed to convert files: {message}" : "Tiedostojen muuntaminen epäonnistui: {message}",
    "All files failed to be converted" : "Mitään tiedostoista ei voitu muuntaa",
    "One file could not be converted: {message}" : "Yhtä tiedostoa ei voitu muuntaa: {message}",
    "Failed to convert files" : "Tiedostojen muuntaminen epäonnistui",
    "File successfully converted" : "Tiedosto muunnettu onnistuneesti",
    "Failed to convert file: {message}" : "Tiedoston muuntaminen epäonnistui: {message}",
    "Failed to convert file" : "Tiedoston muuntaminen epäonnistui",
    "Delete" : "Poista",
    "Leave this share" : "Poistu tästä jaosta",
    "Disconnect storage" : "Katkaise yhteys tallennustilaan",
    "Disconnect storages" : "Katkaise yhteys tallennustiloihin",
    "Delete permanently" : "Poista pysyvästi",
    "Delete and unshare" : "Poista ja lopeta jakaminen",
    "Delete file" : "Poista tiedosto",
    "Delete files" : "Poista tiedostot",
    "Delete folder" : "Poista kansio",
    "Delete folders" : "Poista kansio",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Olet poistamassa {count} kohteen lopullisesti","Olet poistamassa {count} kohdetta lopullisesti"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Olet poistamassa {count} kohteen","Olet poistamassa {count} kohdetta"],
    "Confirm deletion" : "Vahvista poistaminen",
    "Cancel" : "Peruuta",
    "Download" : "Lataa",
    "The requested file is not available." : "Pyydetty tiedosto ei ole saatavilla.",
    "The requested files are not available." : "Pyydetyt tiedostot eivät ole saatavilla.",
    "Moving \"{source}\" to \"{destination}\" …" : "Siirretään \"{source}\" kohteeseen \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Kopioidaan \"{source}\" kohteeseen \"{destination}\" …",
    "Destination is not a folder" : "Kohde ei ole kansio",
    "This file/folder is already in that directory" : "Tämä tiedosto/kansio on jo kyseisessä kansiossa",
    "(copy)" : "(kopioi)",
    "A file or folder with that name already exists in this folder" : "Tiedosto tai kansio tällä nimellä on jo olemassa tässä kansiossa",
    "The files are locked" : "Tiedostot on lukittu",
    "The file does not exist anymore" : "Tiedostoa ei ole enää olemassa",
    "Choose destination" : "Valitse kohde",
    "Copy to {target}" : "Kopioi kohteeseen {target}",
    "Copy" : "Kopioi",
    "Move to {target}" : "Siirrä kohteeseen {target}",
    "Move" : "Siirrä",
    "Move or copy operation failed" : "Siirto- tai kopiointitoiminto epäonnistui",
    "Move or copy" : "Siirrä tai kopioi",
    "Open folder {displayName}" : "Avaa kansio {displayName}",
    "Open in Files" : "Avaa tiedostosovelluksessa",
    "Open locally" : "Avaa paikallisesti",
    "Failed to redirect to client" : "Uudelleenohjaus asiakkaaseen epäonnistui",
    "Open file locally" : "Avaa tiedosto paikallisesti",
    "Retry and close" : "Yritä uudelleen ja sulje",
    "Rename" : "Nimeä uudelleen",
    "Details" : "Tiedot",
    "View in folder" : "Näe kansiossa",
    "Today" : "Tänään",
    "Last 7 days" : "Edelliset 7 päivää",
    "Last 30 days" : "Edelliset 30 päivää",
    "This year ({year})" : "Tämä vuosi ({year})",
    "Last year ({year})" : "Viime vuosi ({year})",
    "Documents" : "Asiakirjat",
    "Spreadsheets" : "Laskentataulukot",
    "Presentations" : "Esitykset",
    "PDFs" : "PDF-tiedostot",
    "Folders" : "Kansiot",
    "Audio" : "Ääni",
    "Images" : "Kuvat",
    "Videos" : "Videot",
    "Created new folder \"{name}\"" : "Luotu uusi kansio \"{name}\"",
    "Unable to initialize the templates directory" : "Mallipohjien kansiota ei voitu alustaa",
    "Create templates folder" : "Luo mallipohjien kansio",
    "Templates" : "Mallipohjat",
    "New template folder" : "Uusi mallipohjien kansio",
    "In folder" : "Kansiossa",
    "Search in all files" : "Etsi kaikista tiedostoista",
    "Search in folder: {folder}" : "Etsi kansiosta: {folder}",
    "One of the dropped files could not be processed" : "Yhtä pudotetuista tiedostoista ei voitu prosessoida",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Selaimesi ei tue Filesystem API -rajapintaa. Kansioita ei lähetetä",
    "No files to upload" : "Ei lähetettäviä tiedostoja",
    "Unable to create the directory {directory}" : "Kansiota {directory} ei voi luoda",
    "Some files could not be uploaded" : "Joitain tiedostoja ei voitu lähettää",
    "Files uploaded successfully" : "Tiedostot lähetetty onnistuneesti",
    "No files to process" : "Ei tiedostoja käsiteltäväksi",
    "Some files could not be copied" : "Joitain tiedostoja ei voitu kopioida",
    "Some files could not be moved" : "Joitain tiedostoja ei voitu siirtää",
    "Files copied successfully" : "Tiedostot kopioitu onnistuneesti",
    "Files moved successfully" : "Tiedostot siirretty onnistuneesti",
    "Upload cancelled" : "Lataus peruutettu",
    "Could not rename \"{oldName}\", it does not exist any more" : "Kohdetta \"{oldName}\" ei voitu nimetä uudelleen, koska sitä ei ole enää olemassa",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nimi \"{newName}\" on jo käytössä kansiossa \"{dir}\". Valitse toinen nimi.",
    "Could not rename \"{oldName}\"" : "Ei voitu nimetä uudelleen \"{oldName}\"",
    "This operation is forbidden" : "Tämä toiminto on kielletty",
    "This folder is unavailable, please try again later or contact the administration" : "Tämä kansio ei ole käytettävissä. Yritä myöhemmin uudlleen tai ota yhteys ylläpitoon",
    "Storage is temporarily not available" : "Tallennustila on tilapäisesti pois käytöstä",
    "Unexpected error: {error}" : "Odottamaton virhe: {error}",
    "_%n file_::_%n files_" : ["%n tiedosto","%n tiedostoa"],
    "_%n folder_::_%n folders_" : ["%n kansio","%n kansiota"],
    "_%n hidden_::_%n hidden_" : ["%n piilotettu","%n piilotettua"],
    "Filename must not be empty." : "Tiedostonimi ei voi olla tyhjä.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" ei ole sallittu tiedoston nimessä.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" on varattu nimi, eikä se ole sallittu nimi tiedostoille.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" ei ole sallitttu tiedostotyyppi.",
    "Filenames must not end with \"{extension}\"." : "Tiedostojen nimet eivät voi päättyä \"{extension}\".",
    "List of favorite files and folders." : "Luettelo suosikkitiedostoista ja -kansioista.",
    "No favorites yet" : "Ei vielä suosikkeja",
    "Files and folders you mark as favorite will show up here" : "Suosikeiksi merkitsemäsi tiedostot ja kansiot näkyvät täällä",
    "List of your files and folders." : "Luettelo tiedostoistasi ja kansioistasi.",
    "Folder tree" : "Kansiopuu",
    "List of your files and folders that are not shared." : "Luettelo tiedostoistasi ja kansioistasi, joita ei ole jaettu.",
    "No personal files found" : "Henkilökohtaisia tiedostoja ei löytynyt",
    "Files that are not shared will show up here." : "Tiedostot, joita ei ole jasettu, näkyvät täällä.",
    "Recent" : "Viimeaikaiset",
    "List of recently modified files and folders." : "Luettelo äskettäin muokatuista tiedostoista ja kansioista.",
    "No recently modified files" : "Ei äskettäin muokattuja tiedostoja",
    "Files and folders you recently modified will show up here." : "Äskettäin muokkaamasi tiedostot ja kansiot näkyvät täällä.",
    "Search" : "Etsi",
    "Search results within your files." : "Hakutulokset tiedostoistasi.",
    "No entries found in this folder" : "Ei kohteita tässä kansiossa",
    "Select all" : "Valitse kaikki",
    "Upload too large" : "Lähetettävä tiedosto on liian suuri",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Lähetettäväksi valitsemasi tiedostot ylittävät palvelimen salliman tiedostokoon rajan.",
    "%1$s (renamed)" : "%1$s (nimetty uudelleen)",
    "Upload (max. %s)" : "Lähetys (enintään %s)",
    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" massatoiminto suoritettu",
    "Filter file names …" : "Suodata tiedostonimiä…",
    "Clipboard is not available" : "Leikepöytä ei ole käytettävissä",
    "WebDAV URL copied to clipboard" : "WebDAV-osoite kopioitu leikepöydälle",
    "Enable the grid view" : "Käytä ruudukkonäkymää",
    "Enable folder tree" : "Ota kansiopuu käyttöön",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Kopioi leikepöydälle",
    "Use this address to access your Files via WebDAV" : "Käytä tätä osoitetta yhdistääksesi tiedostosi WebDAV:in kautta",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Jos sinulla on kaksivaiheinen todennus käytössä, sinun täytyy luoda uusi sovellussalasana ja käyttää sitä napsauttamalla tästä.",
    "Show a warning dialog when changing a file extension." : "Näytä varoitus tiedostopäätettä muuttaessa.",
    "Keyboard shortcuts" : "Pikanäppäimet",
    "Speed up your Files experience with these quick shortcuts." : "Nopeuta tiedostonhallinnan kokemusta näillä pikanäppäimillä.",
    "Open the actions menu for a file" : "Avaa tiedoston toimintovalikko",
    "Rename a file" : "Nimeä tiedosto uudelleen",
    "Delete a file" : "Poista tiedosto",
    "Favorite or remove a file from favorites" : "Lisää tai poista tiedosto suosikeista",
    "Manage tags for a file" : "Hallinnoi tiedosto tunnisteita",
    "Deselect all files" : "Poista kaikkien tiedostojen valinta",
    "Select or deselect a file" : "Valitse tiedosto tai poista sen valinta",
    "Navigate to the parent folder" : "Siirry ylätason kansioon",
    "Navigate to the file above" : "Siirry yllä olevaan tiedostoon",
    "Navigate to the file below" : "Siirry alla olevaan tiedostoon",
    "Navigate to the file on the left (in grid mode)" : "Siirry vasemmalla olevaan tiedostoon (ruudukkotilassa)",
    "Navigate to the file on the right (in grid mode)" : "Siirry oikealla olevaan tiedostoon (ruudukkotilassa)",
    "Toggle the grid view" : "Ruudukkonäkymä päälle/pois",
    "Open the sidebar for a file" : "Avaa tiedoston sivupalkki",
    "Save as …" : "Tallenna nimellä",
    "Converting files …" : "Muunnetaan tiedostoja…",
    "Converting file …" : "Muunnetaan tiedostoa…",
    "Deletion cancelled" : "Poistaminen peruttu",
    "Edit locally" : "Muokkaa paikallisesti",
    "Moving \"{source}\" to \"{destination}\" …" : "Siirretään \"{source}\" kohteeseen \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Kopioidaan \"{source}\" kohteeseen \"{destination}\" …",
    "Move cancelled" : "Siirtäminen peruttu",
    "Cancelled move or copy operation" : "Siirto- tai kopiointitoiminto peruttu",
    "Open details" : "Avaa yksityiskohdat",
    "Photos and images" : "Valokuvat ja kuvat",
    "New folder creation cancelled" : "Kansion luominen peruttu",
    "This directory is unavailable, please check the logs or contact the administrator" : "Hakemisto ei ole käytettävissä. Tarkista lokit tai ole yhteydessä ylläpitoon.",
    "All folders" : "Kaikki kansiot",
    "Search everywhere …" : "Etsi kaikkialta…",
    "Search here …" : "Etsi tästä…",
    "Preparing …" : "Valmistellaan…"
},
"nplurals=2; plural=(n != 1);");
